<?php
/*
Plugin Name: flickr nofollow
Plugin URI: http://www.awokenmind.de/flickr-nofollow
Description: Searches for links to flickr.com and adds a rel="nofollow" tag
Author: Andreas Brett (based on 'Wikipedia nofollow' by Key Yasumoto-Nicolson and 'Identify External Links' by Mark Jaquith)
Version: 1.0.0
Author URI: http://www.awokenmind.de
*/

/* Based on:
Plugin Name: Wikipedia nofollow
Plugin URI: http://whatjapanthinks.com/wikipedia-nofollow/
Description: Searches for links to Wikipedia.org, and adds a rel="nofollow" tag if necessary
Author: Ken Yasumoto-Nicolson (based on Identify External Links by Mark Jaquith)
Version: 1.0
Author URI: http://whatjapanthinks.com
*/

/* Based on:
Plugin Name: Identify External Links
Plugin URI: http://txfx.net/code/wordpress/identify-external-links/
Description: Searches the text for links outside of the domain of the blog.	 To these, it adds <strong>class="extlink"</strong> (and optionally, <strong>target="_blank"</strong>).
Author: Mark Jaquith
Version: 1.3
Author URI: http://txfx.net/
*/

/*	Copyright 2005	Mark Jaquith (email: mark.gpl@txfx.net)
   Additional changes Copyright 2007 Ken Yasumoto-Nicolson (email: seron@whatjapanthinks.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// get domain name from uri
function wp_flickr_nofollow_helper_1($uri) {
	preg_match("/^(http:\/\/)?([^\/]+)/i", $uri, $matches);
	$host = $matches[2];
	preg_match("/[^\.\/]+\.[^\.\/]+$/", $host, $matches);
	return $matches[0];	   
}

// has no rel="nofollow"
function wp_flickr_nofollow_helper_2($text) {
	if ( preg_match("/rel=[\"\'].*?nofollow.*?[\"\']/i", $text ) )
		return false;
	else
		return true;
}
	
function parse_flickr_nofollow($matches) {
	// flickr-link => check for nofollow
	if( wp_flickr_nofollow_helper_1($matches[3]) == "flickr.com" &&
		wp_flickr_nofollow_helper_2($matches[1]) &&
		wp_flickr_nofollow_helper_2($matches[4])) {
			
		// search for existing rel="*" attribute and add nofollow-prefix
		$x = preg_replace("/rel=[\"\'](.*?)[\"\']/i", 'rel="nofollow $1"', $matches[1]);
		$y = preg_replace("/rel=[\"\'](.*?)[\"\']/i", 'rel="nofollow $1"', $matches[4]);
		
		// no changes => just ADD rel="nofollow"
		if($x == $matches[1] && $y == $matches[4]) {
			return '<a href="' . $matches[2] . '//' . $matches[3] . '" ' . $matches[1] . $matches[4] . ' rel="nofollow">' . $matches[5] . '</a>';		
		}
		// there was a rel="*" attribute => use the replaced string from above
		else {
			return '<a href="' . $matches[2] . '//' . $matches[3] . '" ' .  $x . $y . '>' . $matches[5] . '</a>';
		}
	}
	// non-flickr-link or already has nofollow => leave it as it was
	else {
		return '<a href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] . '>' . $matches[5] . '</a>';
	}
}
	

function wp_flickr_nofollow($text)  {
	$pattern = '/<a (.*?)href=[\"\'](.*?)\/\/(.*?)[\"\'](.*?)>(.*?)<\/a>/i';
	$text = preg_replace_callback($pattern,'parse_flickr_nofollow', $text);
	return $text;
}

// filters have high priority to make sure that any markup plugins like Textile or Markdown have already created the HTML links
add_filter('the_content', 'wp_flickr_nofollow', 998);
add_filter('the_excerpt', 'wp_flickr_nofollow', 998);

// delete this one if you don't want it run on comments
add_filter('comment_text', 'wp_flickr_nofollow', 998);
?>